/*
***************************************************************************
*
* Author: Teunis van Beelen
*
* Copyright (C) 2010 Teunis van Beelen
*
* teuniz@gmail.com
*
***************************************************************************
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation version 2 of the License.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License along
* with this program; if not, write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*
***************************************************************************
*
* This version of GPL is at http://www.gnu.org/licenses/old-licenses/gpl-2.0.txt
*
***************************************************************************
*/



#include "export_annotations.h"



UI_ExportAnnotationswindow::UI_ExportAnnotationswindow(QWidget *parent)
{
  int i;

  mainwindow = (UI_Mainwindow *)parent;

  ExportAnnotsDialog = new QDialog;

  ExportAnnotsDialog->setMinimumSize(QSize(800, 180));
  ExportAnnotsDialog->setMaximumSize(QSize(800, 180));
  ExportAnnotsDialog->setWindowTitle("Export annotations");
  ExportAnnotsDialog->setModal(TRUE);
  ExportAnnotsDialog->setAttribute(Qt::WA_DeleteOnClose, TRUE);

  filelist = new QListWidget(ExportAnnotsDialog);
  filelist->setGeometry(QRect(10, 10, 780, 75));
  filelist->setSelectionBehavior(QAbstractItemView::SelectRows);
  filelist->setSelectionMode(QAbstractItemView::SingleSelection);
  for(i=0; i<mainwindow->files_open; i++)
  {
    if((mainwindow->edfheaderlist[i]->edf)||(mainwindow->edfheaderlist[i]->bdf))
    {
      new QListWidgetItem(mainwindow->edfheaderlist[i]->filename, filelist);
    }
  }

  ExportButton = new QPushButton(ExportAnnotsDialog);
  ExportButton->setGeometry(QRect(10, 140, 100, 25));
  ExportButton->setText("Export");

  CloseButton = new QPushButton(ExportAnnotsDialog);
  CloseButton->setGeometry(QRect(690, 140, 100, 25));
  CloseButton->setText("Close");

  QObject::connect(CloseButton,  SIGNAL(clicked()), ExportAnnotsDialog, SLOT(close()));
  QObject::connect(ExportButton, SIGNAL(clicked()), this,               SLOT(ExportButtonClicked()));

  filelist->setCurrentRow(mainwindow->files_open - 1);

  ExportAnnotsDialog->exec();
}



void UI_ExportAnnotationswindow::ExportButtonClicked()
{
  int i, n;

  char path[1024],
       str[1024];

  FILE *inputfile,
       *annotationfile;

  struct annotationblock *annot;


  if(!mainwindow->files_open)
  {
    ExportAnnotsDialog->close();
    return;
  }

  ExportButton->setEnabled(FALSE);
  CloseButton->setEnabled(FALSE);

  for(i=0; i<mainwindow->files_open; i++)
  {
    if(!strcmp(mainwindow->edfheaderlist[i]->filename, filelist->item(filelist->currentRow())->text().toLatin1().data()))
    {
      break;
    }
  }

  if(i==mainwindow->files_open)
  {
    ExportAnnotsDialog->close();
    return;
  }

  n = i;

  inputfile = mainwindow->edfheaderlist[n]->file_hdl;

  QFileDialog fchooser;
  fchooser.setFileMode(QFileDialog::AnyFile);
  fchooser.setAcceptMode(QFileDialog::AcceptSave);
  fchooser.setWindowTitle("Export annotations");
  fchooser.setLabelText(QFileDialog::FileName, "File");
  fchooser.setDefaultSuffix("txt");
  fchooser.setFilter("Text files (*.txt *.TXT)");

  get_filename_from_path(path, mainwindow->edfheaderlist[n]->filename, 1024);
  remove_extension_from_filename(path);
  strcat(path, "_annotations.txt");
  fchooser.selectFile(path);
  if(mainwindow->recent_savedir[0] != 0)
  {
    fchooser.setDirectory(mainwindow->recent_savedir);
  }

  if(!(fchooser.exec() == QDialog::Accepted))
  {
    ExportAnnotsDialog->close();
    return;
  }

  strcpy(mainwindow->recent_savedir, fchooser.directory().absolutePath().toLatin1().data());

  strcpy(path, fchooser.selectedFiles().at(0).toLatin1().data());

  annotationfile = fopen64(path, "wb");
  if(annotationfile==NULL)
  {
    UI_Messagewindow popuperror("Error", "Error, can not open annotationfile for writing.");
    ExportAnnotsDialog->close();
    return;
  }

  fprintf(annotationfile, "Onset,Duration,Annotation\n");

  annot = mainwindow->annotationlist[n];

  while(annot != NULL)
  {
    strncpy(str, annot->annotation, 1024);
    str[1023] = 0;
    utf8_to_latin1(str);

    n = strlen(str);
    for(i=0; i<n; i++)
    {
      if((((unsigned char *)str)[i] < 32) || (((unsigned char *)str)[i] == ','))
      {
        str[i] = '.';
      }
    }

    fprintf(annotationfile, "%+.7f,%s,%s\n", (double)annot->onset / TIME_DIMENSION, annot->duration, str);

    annot = annot->next_annotation;
  }

  fclose(annotationfile);

  ExportAnnotsDialog->close();
}















